@@ -17,10 +17,9 @@
 #' @param type Numeric, type of sums of squares. May be 1, 2 or 3. If 2 or 3,
 #'   ANOVA-tables using `car::Anova()` will be returned. (Ignored for
 #'   `afex_aov`.)
-#' @param ci Confidence Interval (CI) level for effect sizes
-#'   `omega_squared`, `eta_squared` etc. The default, `NULL`,
-#'   will compute no confidence intervals. `ci` should be a scalar between
-#'   0 and 1.
+#' @param ci Confidence Interval (CI) level for effect sizes specified in
+#'   `effectsize_type`. The default, `NULL`, will compute no confidence
+#'   intervals. `ci` should be a scalar between 0 and 1.
 #' @param test String, indicating the type of test for `Anova.mlm` to be
 #'   returned. If `"multivariate"` (or `NULL`), returns the summary of
 #'   the multivariate test (that is also given by the `print`-method). If
@@ -65,24 +64,16 @@
 #' df$Sepal.Big <- ifelse(df$Sepal.Width >= 3, "Yes", "No")
 #'
 #' model <- aov(Sepal.Length ~ Sepal.Big, data = df)
-#' model_parameters(
-#'   model,
-#'   omega_squared = "partial",
-#'   eta_squared = "partial",
-#'   epsilon_squared = "partial"
-#' )
+#' model_parameters(model)
 #'
-#' model_parameters(
-#'   model,
-#'   effectsize_type = c("omega", "eta"),
-#'   ci = .9
-#' )
+#' model_parameters(model, effectsize_type = c("omega", "eta"), ci = 0.9)
 #'
 #' model <- anova(lm(Sepal.Length ~ Sepal.Big, data = df))
 #' model_parameters(model)
 #' model_parameters(
 #'   model,
-#'   effectsize_type = c("omega", "eta", "epsilon")
+#'   effectsize_type = c("omega", "eta", "epsilon"),
+#'   alternative = "greater"
 #' )
 #'
 #' model <- aov(Sepal.Length ~ Sepal.Big + Error(Species), data = df)
@@ -100,7 +91,7 @@
 #' model_parameters(
 #'   model,
 #'   effectsize_type = "eta",
-#'   ci = .9,
+#'   ci = 0.9,
 #'   df_error = dof_satterthwaite(mm)[2:3]
 #' )
 #' }
@@ -123,9 +114,27 @@ model_parameters.aov <- function(model,
                                  ...) {
   ## TODO: remove in a later update
   # handle deprected arguments ------
-  if (!is.null(omega_squared)) effectsize_type <- "omega"
-  if (!is.null(eta_squared)) effectsize_type <- "eta"
-  if (!is.null(epsilon_squared)) effectsize_type <- "epsilon"
+  if (!is.null(omega_squared)) {
+    insight::format_warning(
+      "Argument `omega_squared` is deprecated.",
+      "Please use `effectsize_type = \"omega\"` instead."
+    )
+    effectsize_type <- "omega"
+  }
+  if (!is.null(eta_squared)) {
+    insight::format_warning(
+      "Argument `eta_squared` is deprecated.",
+      "Please use `effectsize_type = \"eta\"` instead."
+    )
+    effectsize_type <- "eta"
+  }
+  if (!is.null(epsilon_squared)) {
+    insight::format_warning(
+      "Argument `epsilon_squared` is deprecated.",
+      "Please use `effectsize_type = \"epsilon\"` instead."
+    )
+    effectsize_type <- "epsilon"
+  }
 
   # save model object, for later checks
   original_model <- model
@@ -189,7 +198,7 @@ model_parameters.aov <- function(model,
   }
 
   # add attributes
-  params <- .add_anova_attributes(params, model, ci, test = test, ...)
+  params <- .add_anova_attributes(params, model, ci, test = test, alternative = alternative, ...)
 
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
   attr(params, "object_name") <- object_name
@@ -296,7 +305,7 @@ model_parameters.afex_aov <- function(model,
   )
 
   # add attributes
-  out <- .add_anova_attributes(out, model, ci, test = NULL, ...)
+  out <- .add_anova_attributes(out, model, ci, test = NULL, alternative = NULL, ...)
 
   # filter parameters
   if (!is.null(keep) || !is.null(drop)) {
@@ -379,6 +388,28 @@ model_parameters.maov <- model_parameters.aov
 }
 
 
+.anova_alternative <- function(params, alternative) {
+  alternative_footer <- NULL
+  if (!is.null(alternative)) {
+    alternative <- match.arg(tolower(alternative), choices = c("two.sided", "greater", "less"))
+    if (alternative != "two.sided") {
+      ci_low <- which(endsWith(colnames(params), "CI_low"))
+      ci_high <- which(endsWith(colnames(params), "CI_high"))
+      if (length(ci_low) && length(ci_high)) {
+        bound <- if (alternative == "less") params[[ci_low[1]]][1] else params[[ci_high[1]]][1]
+        bound <- insight::format_value(bound, digits = 2)
+        side <- if (alternative == "less") "lower" else "upper"
+        alternative_footer <- sprintf(
+          "One-sided CIs: %s bound fixed at [%s].",
+          side, bound
+        )
+      }
+    }
+  }
+  alternative_footer
+}
+
+
 .check_anova_contrasts <- function(model, type) {
   # check only valid for anova tables of type III
   if (!is.null(type) && type == 3) {
@@ -399,18 +430,11 @@ model_parameters.maov <- model_parameters.aov
     )
 
     # try to access data of model predictors
-    predictors <- tryCatch(
-      {
-        insight::get_predictors(model)
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    predictors <- .safe(insight::get_predictors(model))
 
     # if data available, check contrasts and mean centering
     if (!is.null(predictors)) {
-      treatment_contrasts_or_not_centered <- sapply(predictors, function(i) {
+      treatment_contrasts_or_not_centered <- vapply(predictors, function(i) {
         if (is.factor(i)) {
           cn <- stats::contrasts(i)
           if (is.null(cn) || (all(cn %in% c(0, 1)))) {
@@ -422,7 +446,7 @@ model_parameters.maov <- model_parameters.aov
           }
         }
         return(FALSE)
-      })
+      }, TRUE)
     } else {
       treatment_contrasts_or_not_centered <- FALSE
     }
@@ -458,8 +482,7 @@ model_parameters.maov <- model_parameters.aov
   insight::check_if_installed("effectsize", minimum_version = "0.5.0")
 
   # set error-df, when provided.
-  if (!is.null(df_error) &&
-    is.data.frame(model) &&
+  if (!is.null(df_error) && is.data.frame(model) &&
     !any(c("DenDF", "den Df", "denDF", "df_error") %in% colnames(model))) {
     if (length(df_error) > nrow(model)) {
       insight::format_error(
@@ -541,7 +564,8 @@ model_parameters.maov <- model_parameters.aov
 .anova_table_wide <- function(data, ...) {
   wide_anova <- function(x) {
     # creating numerator and denominator degrees of freedom
-    if (length(idxResid <- x$Parameter == "Residuals")) {
+    idxResid <- x$Parameter == "Residuals"
+    if (length(idxResid)) {
       x$df_error <- x$df[idxResid]
       x$Sum_Squares_Error <- x$Sum_Squares[idxResid]
       x$Mean_Square_Error <- x$Sum_Squares[idxResid]
