@@ -103,7 +103,7 @@
 #'
 #' if (require("lme4")) {
 #'   model <- lmer(mpg ~ wt + (1 | gear), data = mtcars)
-#'   model_parameters(model, bootstrap = TRUE, iterations = 50)
+#'   model_parameters(model, bootstrap = TRUE, iterations = 50, verbose = FALSE)
 #' }
 #' }
 #' @return A data frame of indices related to the model's parameters.
@@ -124,18 +124,12 @@ model_parameters.merMod <- function(model,
                                     keep = NULL,
                                     drop = NULL,
                                     verbose = TRUE,
-                                    df_method = ci_method,
                                     include_sigma = FALSE,
                                     vcov = NULL,
                                     vcov_args = NULL,
                                     ...) {
   dots <- list(...)
 
-  ## TODO remove later
-  if (!missing(df_method) && !identical(ci_method, df_method)) {
-    insight::format_error("Argument `df_method` is defunct. Please use `ci_method` instead.")
-  }
-
   # set default
   if (is.null(ci_method)) {
     if (isTRUE(bootstrap)) {
@@ -173,9 +167,9 @@ model_parameters.merMod <- function(model,
   # post hoc standardize only works for fixed effects...
   if (!is.null(standardize) && standardize != "refit") {
     if (!missing(effects) && effects != "fixed" && verbose) {
-      warning(insight::format_message(
+      insight::format_alert(
         "Standardizing coefficients only works for fixed effects of the mixed model."
-      ), call. = FALSE)
+      )
     }
     effects <- "fixed"
   }
@@ -199,9 +193,7 @@ model_parameters.merMod <- function(model,
       if (effects != "fixed") {
         effects <- "fixed"
         if (verbose) {
-          warning(insight::format_message(
-            "Bootstrapping only returns fixed effects of the mixed model."
-          ), call. = FALSE)
+          insight::format_alert("Bootstrapping only returns fixed effects of the mixed model.")
         }
       }
     } else {
@@ -237,7 +229,14 @@ model_parameters.merMod <- function(model,
   }
 
   if (effects %in% c("random", "all") && isFALSE(group_level)) {
-    params_variance <- .extract_random_variances(model, ci = ci, effects = effects, ci_method = ci_method, ci_random = ci_random, verbose = verbose)
+    params_variance <- .extract_random_variances(
+      model,
+      ci = ci,
+      effects = effects,
+      ci_method = ci_method,
+      ci_random = ci_random,
+      verbose = verbose
+    )
   }
 
   # merge random and fixed effects, if necessary
