@@ -4,6 +4,7 @@
 # model parameters -------------
 
 
+#' @rdname model_parameters.stanreg
 #' @export
 model_parameters.blrm <- model_parameters.bayesQR
 
@@ -43,7 +44,17 @@ standard_error.psm <- standard_error.lrm
 #' @export
 p_value.lrm <- function(model, ...) {
   stat <- insight::get_statistic(model)
-  p <- 2 * stats::pt(abs(stat$Statistic), df = degrees_of_freedom(model, method = "any"), lower.tail = FALSE)
+
+  # Issue: 697: typically the degrees of freedom are the same for every
+  # observation, but the value is repeated. This poses problems in multiple
+  # imputation models with Hmisc when we get more df values than parameters.
+  df <- degrees_of_freedom(model, method = "any")
+  dfu <- unique(df)
+  if (length(dfu) == 1) {
+    df <- dfu
+  }
+
+  p <- 2 * stats::pt(abs(stat$Statistic), df = df, lower.tail = FALSE)
 
   .data_frame(
     Parameter = .remove_backticks_from_string(stat$Parameter),
