@@ -92,7 +92,7 @@ parameters_type <- function(model, ...) {
   }
 
 
-  data <- insight::get_data(model, verbose = FALSE)
+  data <- insight::get_data(model, source = "mf", verbose = FALSE)
   if (is.null(data) || inherits(data, "ts") || nrow(data) == 0) {
     return(NULL)
   }
@@ -304,9 +304,7 @@ parameters_type <- function(model, ...) {
     subs <- "\\2"
   }
   p <- "(.*)poly\\((.*),\\s(.*)\\)(.*)"
-  tryCatch(insight::trim_ws(sub(p, replacement = subs, x)),
-    error = function(x) 1
-  )
+  .safe(insight::trim_ws(sub(p, replacement = subs, x)), 1)
 }
 
 
@@ -319,10 +317,10 @@ parameters_type <- function(model, ...) {
   .check_for_numerics <- function(x) {
     is.numeric(x) && !isTRUE(attributes(x)$factor)
   }
-  out$numeric <- names(data[sapply(data, .check_for_numerics)])
+  out$numeric <- names(data[vapply(data, .check_for_numerics, TRUE)])
 
   # get contrast coding
-  contrast_coding <- tryCatch(model$contrasts, error = function(e) NULL)
+  contrast_coding <- .safe(model$contrasts)
 
   # if contrasts are given as matrix, find related contrast name
   if (!is.null(contrast_coding)) {
@@ -351,10 +349,10 @@ parameters_type <- function(model, ...) {
   }
 
   # Ordered factors
-  out$ordered <- names(data[vapply(data, is.ordered, logical(1))])
+  out$ordered <- names(data[vapply(data, is.ordered, TRUE)])
 
   # Factors
-  out$factor <- names(data[vapply(data, is.factor, logical(1)) | vapply(data, is.character, logical(1))])
+  out$factor <- names(data[vapply(data, is.factor, TRUE) | vapply(data, is.character, TRUE)])
 
   out$levels <- NA
   out$levels_parent <- NA
