@@ -42,6 +42,7 @@
 #' @param ... Arguments passed to or from other methods.
 #' @param pca_results The output of the `principal_components()` function.
 #' @param digits,labels Arguments for `print()`.
+#' @param verbose Toggle warnings.
 #' @inheritParams n_factors
 #'
 #' @details
@@ -166,7 +167,7 @@
 #'
 #' efa <- factor_analysis(mtcars[, 1:5], n = 2)
 #' summary(efa)
-#' predict(efa)
+#' predict(efa, verbose = FALSE)
 #'
 #' \donttest{
 #' # Automated number of components
@@ -207,7 +208,7 @@ principal_components <- function(x,
 
 #' @rdname principal_components
 #' @export
-rotated_data <- function(pca_results) {
+rotated_data <- function(pca_results, verbose = TRUE) {
   original_data <- attributes(pca_results)$dataset
   rotated_matrix <- insight::get_predicted(attributes(pca_results)$model)
   out <- NULL
@@ -215,7 +216,9 @@ rotated_data <- function(pca_results) {
   if (!is.null(original_data) && !is.null(rotated_matrix)) {
     compl_cases <- attributes(pca_results)$complete_cases
     if (is.null(compl_cases) && nrow(original_data) != nrow(rotated_matrix)) {
-      insight::format_warning("Could not retrieve information about missing data.")
+      if (verbose) {
+        insight::format_warning("Could not retrieve information about missing data.")
+      }
       return(NULL)
     }
     original_data$.parameters_merge_id <- seq_len(nrow(original_data))
@@ -223,7 +226,9 @@ rotated_data <- function(pca_results) {
     out <- merge(original_data, rotated_matrix, by = ".parameters_merge_id", all = TRUE, sort = FALSE)
     out$.parameters_merge_id <- NULL
   } else {
-    insight::format_warning("Either the original or the rotated data could not be retrieved.")
+    if (verbose) {
+      insight::format_warning("Either the original or the rotated data could not be retrieved.")
+    }
     return(NULL)
   }
   out
@@ -415,6 +420,10 @@ principal_components.data.frame <- function(x,
   } else if (n >= ncol(x)) {
     n <- ncol(x) - 1
   }
+  # sanity check - we need at least two factors
+  if (n < 2 && ncol(x) >= 2) {
+    n <- 2
+  }
   n
 }
 
