@@ -57,9 +57,7 @@ standardise_posteriors <- standardize_posteriors
   method <- .cant_smart_or_posthoc(method, model, mi, pars$Parameter)
 
   if (robust && method == "pseudo") {
-    warning("`robust` standardization not available for `pseudo` method.",
-      call. = FALSE
-    )
+    insight::format_alert("`robust` standardization not available for `pseudo` method.")
     robust <- FALSE
   }
 
